@@ -1,12 +1,11 @@
 import json
 from LTO import PyCLTO
 from LTOCli import HandleDefault as handle
-from LTO.Transactions.Transfer import Transfer
-from LTOCli import Config
 import sys
-from LTO.Transaction import Transaction
 
 def func(nameSpace, parser):
+    chainId = handle.check(nameSpace.network[0], parser) if nameSpace.network else 'L'
+    accountName = vars(nameSpace)['account'][0] if vars(nameSpace)['account'] else ''
     txJson = nameSpace.stdin.read() if not sys.stdin.isatty() else ""
     if not json:
         parser.error("Expected transaction as input, type 'lto broadcast --help' for instructions")
@@ -15,18 +14,15 @@ def func(nameSpace, parser):
 
     if vars(nameSpace)['unsigned'] is False:
         if not transaction.proofs:
-            if vars(nameSpace)['account']:
-                transaction.signWith(handle.getAccountFromName(vars(nameSpace)['account'][0], parser))
-            else:
-                transaction.signWith(handle.getDefaultAccount(parser))
+            transaction.signWith(handle.getAccount(chainId, parser, accountName))
         if vars(nameSpace)['no_broadcast'] is False:
-            transaction = transaction.broadcastTo(handle.getNode())
+            transaction = transaction.broadcastTo(handle.getNode(chainId, parser))
     else:
         if not transaction.proofs:
             parser.error("Transaction needs to be signed before broadcasting, type 'lto broadcast --help' for instruction")
         else:
             if vars(nameSpace)['no_broadcast'] is False:
-                transaction = transaction.broadcastTo(handle.getNode())
+                transaction = transaction.broadcastTo(handle.getNode(chainId, parser))
 
     handle.prettyPrint(transaction)
 
