@@ -4,19 +4,18 @@ import sys
 import re
 
 def func(nameSpace, parser):
+    chainId = handle.check(nameSpace.network[0], parser) if nameSpace.network else 'L'
+    accountName = vars(nameSpace)['account'][0] if vars(nameSpace)['account'] else ''
     stdin = nameSpace.stdin.read().splitlines() if not sys.stdin.isatty() else []
     if not stdin:
         parser.error('Type lto mass-transfer --help for instructions')
     transfers = processInput(stdin)
     transaction = MassTransfer(transfers)
-    transaction.signWith(handle.getDefaultAccount(parser))
     if vars(nameSpace)['unsigned'] is False:
-        if vars(nameSpace)['account']:
-            transaction.signWith(handle.getAccountFromName(vars(nameSpace)['account'][0], parser))
-        else:
-            transaction.signWith(handle.getDefaultAccount(parser))
+        transaction.signWith(handle.getAccount(chainId, parser, accountName))
+
         if vars(nameSpace)['no_broadcast'] is False:
-            transaction = transaction.broadcastTo(handle.getNode())
+            transaction = transaction.broadcastTo(handle.getNode(chainId, parser))
     elif vars(nameSpace)['no_broadcast'] is False:
         parser.error(
             "Use the '--unsigned' option only in combination with the '--no-broadcast' option. Type 'lto mass-transfer --help' for more informations ")
